==> engine-xml-10.0.0-1126.113-sources.jar: com/xebialabs/xltype/serialization/xstream/ConfigurationItemIdConverter.java <==
/**
 * Copyright 2014-2019 XebiaLabs Inc. and its affiliates. Use is subject to terms of the enclosed Legal Notice.
 */
package com.xebialabs.xltype.serialization.xstream;

import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;

import com.xebialabs.deployit.engine.api.dto.ConfigurationItemId;
import com.xebialabs.deployit.plugin.api.reflect.Type;

@XStreamProvider(tagName = "ci", readable = ConfigurationItemId.class)
public class ConfigurationItemIdConverter implements Converter {
    @Override
    public void marshal(Object source, HierarchicalStreamWriter writer, MarshallingContext context) {
        ConfigurationItemId ciId = (ConfigurationItemId) source;
        writer.addAttribute("ref", ciId.getId());
        if (ciId.getType() != null) {
            writer.addAttribute("type", ciId.getType().toString());
        }
    }

    @Override
    public Object unmarshal(HierarchicalStreamReader reader, UnmarshallingContext context) {
        String id = reader.getAttribute("ref");
        Type type = null;
        if (reader.getAttribute("type") != null) {
            type = Type.valueOf(reader.getAttribute("type"));
        }
        return new ConfigurationItemId(id, type);
    }

    @SuppressWarnings("rawtypes")
    @Override
    public boolean canConvert(Class type) {
        return ConfigurationItemId.class.isAssignableFrom(type);
    }
}

==> engine-xml-25.1.0-512.700-sources.jar: com/xebialabs/xltype/serialization/xstream/ConfigurationItemIdConverter.java <==
/**
 * Copyright 2014-2019 XebiaLabs Inc. and its affiliates. Use is subject to terms of the enclosed Legal Notice.
 */
package com.xebialabs.xltype.serialization.xstream;

import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;

import com.xebialabs.deployit.engine.api.dto.ConfigurationItemId;
import com.xebialabs.deployit.engine.api.dto.ConfigurationItemIdAndReferenceId;
import com.xebialabs.deployit.plugin.api.reflect.Type;

@XStreamProvider(tagName = "ci", readable = ConfigurationItemId.class)
public class ConfigurationItemIdConverter implements Converter {
    @Override
    public void marshal(Object source, HierarchicalStreamWriter writer, MarshallingContext context) {
        ConfigurationItemId ciId = (ConfigurationItemId) source;
        writer.addAttribute("ref", ciId.getId());
        if (ciId.getType() != null) {
            writer.addAttribute("type", ciId.getType().toString());
        }
        if (ciId instanceof ConfigurationItemIdAndReferenceId) {
            writer.addAttribute("reference-id", ((ConfigurationItemIdAndReferenceId) ciId).getReferenceId());
        }
    }

    @Override
    public Object unmarshal(HierarchicalStreamReader reader, UnmarshallingContext context) {
        String id = reader.getAttribute("ref");
        Type type = null;
        if (reader.getAttribute("type") != null) {
            type = Type.valueOf(reader.getAttribute("type"));
        }
        return new ConfigurationItemId(id, type);
    }

    @SuppressWarnings("rawtypes")
    @Override
    public boolean canConvert(Class type) {
        return ConfigurationItemId.class.isAssignableFrom(type);
    }
}
